package com.artfess.portal.kh.controller;


import com.artfess.base.annotation.ApiGroup;
import com.artfess.base.constants.ApiGroupConsts;
import com.artfess.base.controller.BaseController;
import com.artfess.base.enums.ResponseErrorEnums;
import com.artfess.base.model.CommonResult;
import com.artfess.base.query.PageList;
import com.artfess.base.query.QueryFilter;
import com.artfess.base.valid.AddGroup;
import com.artfess.base.valid.UpdateGroup;
import com.artfess.portal.kh.manager.KhResultManager;
import com.artfess.portal.kh.model.KhResult;
import com.artfess.portal.kh.model.KhScheme;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDate;

/**
 * 考核结果信息 前端控制器
 *
 * @company 阿特菲斯信息技术有限公司
 * @author min.wu
 * @since 2024-02-20
 */
@Slf4j
@RestController
@Api(tags = "绩效考核-考核结果信息")
@RequestMapping("/kh/result/")
@ApiGroup(group = {ApiGroupConsts.GROUP_SYSTEM})
public class KhResultController extends BaseController<KhResultManager, KhResult> {

    @Override
    @GetMapping("/{id}")
    @ApiOperation("根据id查询实体")
    public KhResult getById(@ApiParam(name = "id", value = "实体id") @PathVariable String id) {
        return baseService.findById(id);
    }


    @Override
    @PostMapping("/")
    @ApiOperation("添加实体的接口")
    public CommonResult<String> create(@ApiParam(name = "model", value = "实体信息") @RequestBody @Validated({AddGroup.class}) KhResult t) {
        boolean result = baseService.createInfo(t);
        if (!result) {
            return new CommonResult<>(ResponseErrorEnums.FAIL_OPTION, null);
        }
        return new CommonResult<String>();
    }


    @Override
    @PutMapping("/")
    @ApiOperation("更新实体")
    public CommonResult<String> updateById(@ApiParam(name = "model", value = "实体信息") @RequestBody @Validated({UpdateGroup.class}) KhResult t) {
        boolean result = baseService.updateInfo(t);
        if (!result) {
            return new CommonResult<>(ResponseErrorEnums.FAIL_OPTION, null);
        }
        return new CommonResult<String>();
    }

    @Override
    @PostMapping(value = "/query", produces = {"application/json; charset=utf-8"})
    @ApiOperation("分页查询结果")
    public PageList<KhResult> query(@ApiParam(name = "queryFilter", value = "分页查询信息") @RequestBody QueryFilter<KhResult> queryFilter) {
        PageList<KhResult> query = baseService.query(queryFilter);
        query.getRows().forEach(khResult -> {
//            if(khResult.getEndDate().isAfter(LocalDate.now())) {
//                khResult.setStatus("end");
//            }
            if(khResult.getStartDate().isAfter(LocalDate.now())) {
                khResult.setStatus("draft");
            }
        });
        return query;
    }
}
